@@ -1,9 +1,15 @@
+from __future__ import print_function, unicode_literals
+from future.builtins import input, int
 from optparse import make_option
-from urlparse import urlparse
+try:
+    from urllib.parse import urlparse
+except:
+    from urlparse import urlparse
 
 from django.contrib.redirects.models import Redirect
 from django.contrib.sites.models import Site
 from django.core.management.base import BaseCommand, CommandError
+from django.utils.encoding import force_text
 from django.utils.html import strip_tags
 
 from mezzanine.blog.models import BlogPost, BlogCategory
@@ -64,9 +70,9 @@ class BaseImporterCommand(BaseCommand):
         if comments is None:
             comments = []
         self.posts.append({
-            "title": title,
+            "title": force_text(title),
             "publish_date": pub_date,
-            "content": content,
+            "content": force_text(content),
             "categories": categories,
             "tags": tags,
             "comments": comments,
@@ -126,7 +132,7 @@ class BaseImporterCommand(BaseCommand):
                 continue
             while len(value) > max_length:
                 encoded_value = value.encode("utf-8")
-                new_value = raw_input("The value for the field %s.%s exceeds "
+                new_value = input("The value for the field %s.%s exceeds "
                     "its maximum length of %s chars: %s\n\nEnter a new value "
                     "for it, or press return to have it truncated: " %
                     (model.__name__, field_name, max_length, encoded_value))
@@ -174,21 +180,21 @@ class BaseImporterCommand(BaseCommand):
                 setattr(post, k, v)
             post.save()
             if created and verbosity >= 1:
-                print "Imported post: %s" % post
+                print("Imported post: %s" % post)
             for name in categories:
                 cat = self.trunc(BlogCategory, prompt, title=name)
                 if not cat["title"]:
                     continue
                 cat, created = BlogCategory.objects.get_or_create(**cat)
                 if created and verbosity >= 1:
-                    print "Imported category: %s" % cat
+                    print("Imported category: %s" % cat)
                 post.categories.add(cat)
             for comment in comments:
                 comment = self.trunc(ThreadedComment, prompt, **comment)
                 comment["site"] = site
                 post.comments.add(ThreadedComment(**comment))
                 if verbosity >= 1:
-                    print "Imported comment by: %s" % comment["user_name"]
+                    print("Imported comment by: %s" % comment["user_name"])
             self.add_meta(post, tags, prompt, verbosity, old_url)
 
         # Create any pages imported (Wordpress can include pages)
@@ -212,7 +218,7 @@ class BaseImporterCommand(BaseCommand):
             page["in_menus"] = in_menus
             page, created = RichTextPage.objects.get_or_create(**page)
             if created and verbosity >= 1:
-                print "Imported page: %s" % page
+                print("Imported page: %s" % page)
             self.add_meta(page, tags, prompt, verbosity, old_url)
             parents.append({
                 'old_id': old_id,
@@ -238,7 +244,7 @@ class BaseImporterCommand(BaseCommand):
             keyword, created = Keyword.objects.get_or_create_iexact(**keyword)
             obj.keywords.add(AssignedKeyword(keyword=keyword))
             if created and verbosity >= 1:
-                print "Imported tag: %s" % keyword
+                print("Imported tag: %s" % keyword)
         if old_url is not None:
             old_path = urlparse(old_url).path
             if not old_path.strip("/"):
@@ -249,7 +255,7 @@ class BaseImporterCommand(BaseCommand):
             redirect.new_path = obj.get_absolute_url()
             redirect.save()
             if created and verbosity >= 1:
-                print "Created redirect for: %s" % old_url
+                print("Created redirect for: %s" % old_url)
 
     def handle_import(self, options):
         """
