@@ -1,6 +1,6 @@
 from __future__ import unicode_literals
 
-from django.conf.urls import patterns, include
+from django.conf.urls import patterns, include, url
 from django.contrib.admin.sites import AdminSite
 
 from mezzanine.utils.importing import import_dotted_path
@@ -43,5 +43,17 @@ class LazyAdminSite(AdminSite):
                 fb_urls = import_dotted_path("%s.sites.site" % fb_name).urls
             except ImportError:
                 fb_urls = "%s.urls" % fb_name
-            urls += patterns("", ("^media-library/", include(fb_urls)),)
+            urls = patterns("", ("^media-library/", include(fb_urls)),) + urls
+        # Give the urlpatterm for the user password change view an
+        # actual name, so that it can be reversed with multiple
+        # languages are supported in the admin.
+        for admin in self._registry.values():
+            user_change_password = getattr(admin, "user_change_password", None)
+            if user_change_password:
+                urls = patterns("",
+                    url("^auth/user/(\d+)/password/$",
+                        self.admin_view(user_change_password),
+                        name="user_change_password"),
+                ) + urls
+                break
         return urls
