@@ -246,7 +246,7 @@ class Page(BasePage):
 
         # Is the current page me or any page up the parent chain?
         def is_c_or_a(page_id):
-            parent_id = context["_parent_page_ids"].get(page_id)
+            parent_id = context.get("_parent_page_ids", {}).get(page_id)
             return self.id == page_id or (parent_id and is_c_or_a(parent_id))
         self.is_current_or_ascendant = lambda: bool(is_c_or_a(current_page_id))
         self.is_current_parent = self.id == current_parent_id
