@@ -71,7 +71,7 @@ def set_dynamic_settings(s):
     s.setdefault("STATICFILES_FINDERS", defaults.STATICFILES_FINDERS)
     tuple_list_settings = ["AUTHENTICATION_BACKENDS", "INSTALLED_APPS",
                            "MIDDLEWARE_CLASSES", "STATICFILES_FINDERS",
-                           "LANGUAGES"]
+                           "LANGUAGES", "TEMPLATE_CONTEXT_PROCESSORS"]
     for setting in tuple_list_settings[:]:
         if not isinstance(s.get(setting, []), list):
             s[setting] = list(s[setting])
@@ -80,6 +80,18 @@ def set_dynamic_settings(s):
             # the list of settings we'll revert back to tuples.
             tuple_list_settings.remove(setting)
 
+    # From Mezzanine 3.1.2 and onward we added the context processor
+    # for handling the page variable in templates - here we help
+    # upgrading by adding it if missing, with a warning. This helper
+    # can go away eventually.
+    cp = "mezzanine.pages.context_processors.page"
+    if ("mezzanine.pages" in s["INSTALLED_APPS"] and
+            cp not in s["TEMPLATE_CONTEXT_PROCESSORS"]):
+        warn("%s is required in the TEMPLATE_CONTEXT_PROCESSORS setting. "
+             "Adding it now, but you should update settings.py to "
+             "explicitly include it." % cp)
+        append("TEMPLATE_CONTEXT_PROCESSORS", cp)
+
     # Set up cookie messaging if none defined.
     storage = "django.contrib.messages.storage.cookie.CookieStorage"
     s.setdefault("MESSAGE_STORAGE", storage)
@@ -141,6 +153,15 @@ def set_dynamic_settings(s):
     # Ensure Grappelli is after Mezzanine in app order so that
     # admin templates are loaded in the correct order.
     grappelli_name = s.get("PACKAGE_NAME_GRAPPELLI")
+    if s["TESTING"]:
+        # Optional apps aren't installed when testing, but we need
+        # grappelli to perform some admin tests for certain HTML.
+        try:
+            __import__(grappelli_name)
+        except ImportError:
+            pass
+        else:
+            append("INSTALLED_APPS", grappelli_name)
     try:
         move("INSTALLED_APPS", grappelli_name, len(s["INSTALLED_APPS"]))
     except ValueError:
